#!/usr/bin/perl
#
# Auteur : Matthias Hawran
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.
#
use strict;

use File::Basename;
use Getopt::Long;
use Pod::Usage;
use Term::ANSIColor;
use Env;

###############################################################################
# Variables
###############################################################################
# printing vars
my $ascii   = 0;

# command line
$main::myname = basename $0;


###############################################################################
# Functions
###############################################################################

#----------------------------------------------------------------------
# commandLineParsing
#    parse the command line parameters
# 
# input:
#    - the commande line parameters to be parsed
# note:
#    - none
# return:
#    - none
#
#----------------------------------------------------------------------
sub commandLineParsing
{
  my %h_options;
  unless (Getopt::Long::GetOptions(\%h_options,
                                   "ascii",
                                   "help|?",
                                   "man"))
  {
    warn "$main::myname: Error: Command line error\n";
    pod2usage(-verbose => 1, -output => \*STDERR);
  }
  
  pod2usage(-verbose => 1, -exitval => 0) if (exists $h_options{help});
  pod2usage(-verbose => 2, -exitval => 0) if (exists $h_options{man});
  
  $ascii = $h_options{ascii} if (exists $h_options{ascii});
  
  # Simple way to disable color on 'color' and 'colored' functions
  $ENV{ANSI_COLORS_DISABLED}=1 if($ascii);

}


###############################################################################
# MAIN
###############################################################################
&commandLineParsing;


# POD section -----------------------------------------------------------------

=pod

=head1 NAME

test.pl - test bzr + lp

=head1 SYNOPSIS

test bzr + lp connections

B<test.pl> [ -hm ]

=head1 DESCRIPTION

To test bzr + lp

=head1 OPTIONS

=over 8

=item B<-help>

To get help

=item B<-man>

To get man

=back

=head1 AUTHOR

Matthias Hawran <matthias@hawran.net>

=cut

